@@ -6,39 +6,63 @@ contains `System` class
 """
 
 import logging
+import sys
 import threading
 import typing
 from typing import Tuple
-from supbot import looper
+from supbot import looper, g
 from supbot.model import ActionBuffer, Event
 
 if typing.TYPE_CHECKING:
     from supbot.api import Supbot
 
 
+# noinspection PyMethodMayBeStatic
 class System:
     """
     maintains shared states, and makes different states work together,
     provides interface to `Supbot` to control internal systems of supbot
     """
 
-    def __init__(self, supbot: 'Supbot', device_name: str):
+    def __init__(self, supbot: 'Supbot'):
         """
         Initialize shared states: action buffer, logger, status, which is used for different systems to comunicate
         initializes looper thread
         :param supbot: reference for the `Supbot` object, used to retrieve events at runtime
         """
+
+        class PrintStreamHandler(logging.StreamHandler):
+            def __init__(self):
+                logging.StreamHandler.__init__(self)
+
+            def emit(self, record):
+                msg = self.format(record)
+                print(msg)
+
         logging.getLogger("selenium").setLevel(logging.ERROR)
         logging.getLogger("urllib3").setLevel(logging.ERROR)
+        logging.getLogger("appium").setLevel(logging.DEBUG)
 
         logging.basicConfig(level=logging.DEBUG)
-        logger = logging.getLogger("supbot")
 
+        logging.getLogger().handlers = []
+
+        g.logger = logging.getLogger("supbot")
+        FORMAT = "%(name)s - %(levelname)s - %(message)s"
+        handler = PrintStreamHandler()
+        handler.setFormatter(logging.Formatter(fmt=FORMAT))
+        g.logger.addHandler(handler)
+
+        appium_logs = logging.getLogger('appium')
+        fh = logging.FileHandler('appium.log')
+        appium_logs.addHandler(fh)
+
+        self.status = 1
         self._action_buffer: ActionBuffer = []
-        self._logger = logger
-        self._status = True
-        self._looper_thread = threading.Thread(target=looper.start, args=(self, device_name))
+        self._logger = g.logger
+        self._looper_thread = threading.Thread(target=looper.start, args=(self,))
         self._supbot = supbot
+        g.system = self
 
     @property
     def logger(self):
@@ -77,7 +101,7 @@ class System:
         Turns `_status` flag False
         used to tell other systems, that supbot has to be turned off
         """
-        self._status = False
+        self.status = 0
 
     def call_event(self, event: Event, params: Tuple):
         """
@@ -94,4 +118,11 @@ class System:
         Used to check `_status` flag
         :return: `_status` flag
         """
-        return self._status
+        return self.status > 0
+
+    def has_started(self) -> bool:
+        """
+        Used to check `_status` flag
+        :return: `_status` flag
+        """
+        return self.status > 1
